
uniform sampler2D DiffuseMap;
uniform bool diffuseStatus;

uniform sampler2DShadow ShadowMap;
uniform float Epsilon;

varying vec4 ShadowCoord;

varying vec4 diffuse, ambient;
varying vec3 normal, lightDir, halfVector;


vec4 ppLightingFrag()
{
	vec3 n,halfV,viewV,ldir;
	float NdotL,NdotHV;
	vec4 color = ambient;	
	
	n = normalize(normal);
	
	NdotL = max(dot(n,lightDir),0.0);

	if (NdotL > 0.0) {
		halfV = normalize(halfVector);
		NdotHV = max(dot(n,halfV),0.0);
		
		// todo in other pass
		color += gl_FrontMaterial.specular * gl_LightSource[0].specular * pow(NdotHV,gl_FrontMaterial.shininess);
		color += diffuse * NdotL;
	}

	color.a = gl_FrontMaterial.diffuse.a;
	
	return color;
}

float lookup(vec2 vary)
{
	  float depth = shadow2DProj(ShadowMap, ShadowCoord + vec4(vary.x, vary.y, 0, 0) * Epsilon).x;
    return depth != 1.0 ? 0.5 : 1.0;
}
 
void main()
{   	
	float shadeFactor = lookup(vec2(0.0, 0.0));
	
	vec4 pixelColor;
	
	if(diffuseStatus)
		pixelColor = ppLightingFrag() * texture2D(DiffuseMap, gl_TexCoord[2].xy);
	else
		pixelColor = ppLightingFrag();
	
	gl_FragColor = vec4(shadeFactor * pixelColor.rgb, pixelColor.a);
	// gl_FragColor = vec4(pixelColor.rgb, pixelColor.a);
	
	
}