
uniform sampler2DShadow		depthTexture;
uniform float				dt;

varying vec3				N, V, L;
varying vec4				q;

void main(void)
{
	vec3 R = -normalize(reflect(L, N));
	
	vec4 ambient = gl_FrontLightProduct[0].ambient;
	vec4 diffuse = gl_FrontLightProduct[0].diffuse * max(dot(N, L), 0.0);
	vec4 specular = gl_FrontLightProduct[0].specular * pow(max(dot(R, V), 0.0), gl_FrontMaterial.shininess);
	
	vec3 coord = 0.5 * (q.xyz / q.w + 1.0);

#if defined PCF
	float shadow0 = shadow2D(depthTexture, coord).r;
	float shadow1 = shadow2D(depthTexture, coord + vec3(0.0, dt, 0.0)).r;
	float shadow2 = shadow2D(depthTexture, coord + vec3(dt, dt, 0.0)).r;
	float shadow3 = shadow2D(depthTexture, coord + vec3(dt, 0.0, 0.0)).r;
	float shadow = 0.25 * (shadow0 + shadow1 + shadow2 + shadow3);
#else
	//float shadow = texture2D(depthTexture, coord.st).r < coord.z ? 0.0 : 1.0;
	float shadow = shadow2D(depthTexture, coord).r;
#endif

	//	Mark Kilgard's suggestion
	//  gl_FragColor = (ambient + (dimming + (1.0 - dimming) * shadow) * diffuse) * decal + specular * shadow;
	gl_FragColor = (ambient + (0.2 + 0.8 * shadow) * diffuse) + specular * shadow;
	gl_FragColor.a = gl_FrontMaterial.diffuse.a;
}
